# etlsassist

etlassist is a python package supporting ETL operations


## How to install etlassist

```shell
pip install etlassist
```

## How to use etlassist

follow this article for better understanding and usage of etlassist